import random

def hewwwo(main_str):
    strm = main_str
    stri = strm.replace('r', 'w')
    strin = stri.replace('l' , 'w')
    string = strin.replace('n' , 'ny')
    print(string + ' ' + random.choice(["uwu", "owo", ""]))